## gato_eda
---
This repo contains code for gato_eda, it is a library dedicated to EDA.
It is under construction, and is experimental.
It has been built on top of pandas, numpy, statsmodels, matplotlib, seaborn.

Any question of concerns please contact 

 `mario.hevia@gmail.com`